%define libname %mklibname sbuild 1.7.2
%define devname %mklibname -d sbuild

Name: schroot
Version: 1.7.2
Release: %mkrel 29
Summary: Execute commands in a chroot environment
Group: Development/Other
License: GPLv3+
URL: https://codeberg.org/shelter/reschroot
Source0: https://ftp.debian.org/debian/pool/main/s/schroot/%{name}_%{version}.orig.tar.xz
Patch0: schroot-pam.patch
Patch1: schroot-default-config-path.patch
Patch2: schroot-1.7.2-regex.patch
Patch3: schroot-1.7.2-gtest-1.7.0.patch
Patch27: schroot-po4a.patch
Patch28: 6f7166a285e1e97aea390be633591f9791b29a6d.patch
Patch29: schroot-build-with-C-17.patch
Patch30: schroot-boost1.85.patch
BuildRequires: pam-devel
BuildRequires: boost-devel
BuildRequires: pkgconfig(lockdev)
BuildRequires: gettext
BuildRequires: pkgconfig(uuid)
BuildRequires: lvm2
BuildRequires: pkgconfig(cppunit)
BuildRequires: btrfs-progs
BuildRequires: debootstrap
BuildRequires: fakeroot
BuildRequires: groff
BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: gtest-devel
BuildRequires: po4a

Recommends: lvm2
Recommends: btrfs-progs

%description
schroot allows users to execute commands or interactive shells in
different chroots.  Any number of named chroots may be created, and
access permissions given to each, including root access for normal
users, on a per-user or per-group basis.  Additionally, schroot can
switch to a different user in the chroot, using PAM for
authentication and authorisation.  
All operations are logged for security.

Several different types of chroot are supported, including normal
directories in the filesystem, and also block devices.  Sessions,
persistent chroots created on the fly from files (tar with optional
compression and zip) and LVM snapshots are also supported.

schroot supports kernel personalities, allowing the programs run
inside the chroot to have a different personality.  For example,
running 32-bit chroots on 64-bit systems, or even running binaries
from alternative operating systems such as SVR4 or Xenix.

schroot also integrates with sbuild, to allow building packages with
all supported chroot types, including session-managed chroot types
such as LVM snapshots.

schroot shares most of its options with dchroot, but offers vastly
more functionality.

%package -n dchroot
Group: Development/Other
Summary: Older tool similar to schroot

%description -n dchroot
dchroot allows users to execute commands or interactive shells in different 
chroots. Users can move between chroots as necessary. Enhanced functionality 
is available in the next generation tool called schroot.

%package -n %libname
Group: Development/Other
Summary: sbuild library for schroot and dchroot


%description -n %libname
sbuild library for schroot and dchroot

%package -n %devname
Group: Development/Other
Summary: Development files for schroot and dchroot
Requires: %libname = %version
Provides: schroot-devel

%description -n %devname
Development files for schroot and dchroot


%prep
%setup -q
%patch -P0 -p0
%patch -P1 -p0
%patch -P2 -p0
%patch -P3 -p1 -b .gtest17
%patch -P27 -p1
%patch -P28 -p1
%patch -P29 -p1
%patch -P30 -p1

# Remove -Wall
sed -i -e 's/-Wall\s\+//g' cmake/CompilerChecks.cmake

%build
%cmake  -DCMAKE_INSTALL_LOCALSTATEDIR=%{_localstatedir} \
	-DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
	-Dlvm-snapshot=ON \
	-Dbtrfs-snapshot=ON \
	-Ddchroot=ON \
	-Ddchroot-dsa=ON \
	-DBTRFS_EXECUTABLE=%{_sbindir}/btrfs \
	-DLVCREATE_EXECUTABLE=%{_sbindir}/lvcreate \
	-DLVREMOVE_EXECUTABLE=%{_sbindir}/lvremove
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_localstatedir}/lib/schroot/session
mkdir -p %{buildroot}%{_sysconfdir}/schroot/chroot.d
/sbin/ldconfig -n %{buildroot}/%{_libdir}

sed -i 's/\${GIT_RELEASE_VERSION}/%{version}/' %{buildroot}%{_libdir}/pkgconfig/sbuild.pc

%find_lang %{name}

%files -f %{name}.lang
%doc COPYING AUTHORS ChangeLog HACKING NEWS README THANKS TODO
%{_bindir}/schroot
%dir %{_sysconfdir}/schroot
%dir %{_sysconfdir}/schroot/chroot.d
%config(noreplace) %{_sysconfdir}/schroot/schroot.conf
%config(noreplace) %{_sysconfdir}/pam.d/schroot
%dir %{_sysconfdir}/schroot/setup.d
%{_sysconfdir}/bash_completion.d/schroot
%{_sysconfdir}/schroot/default/copyfiles
%{_sysconfdir}/schroot/default/fstab
%{_sysconfdir}/schroot/default/nssdatabases
%{_sysconfdir}/schroot/desktop/copyfiles
%{_sysconfdir}/schroot/desktop/fstab
%{_sysconfdir}/schroot/desktop/nssdatabases
%{_sysconfdir}/schroot/minimal/copyfiles
%{_sysconfdir}/schroot/minimal/fstab
%{_sysconfdir}/schroot/minimal/nssdatabases
%{_sysconfdir}/schroot/buildd/copyfiles
%{_sysconfdir}/schroot/buildd/fstab
%{_sysconfdir}/schroot/buildd/nssdatabases
%{_sysconfdir}/schroot/sbuild/copyfiles
%{_sysconfdir}/schroot/sbuild/fstab
%{_sysconfdir}/schroot/sbuild/nssdatabases
%{_sysconfdir}/schroot/setup.d/00check
%{_sysconfdir}/schroot/setup.d/05btrfs
%{_sysconfdir}/schroot/setup.d/05file
%{_sysconfdir}/schroot/setup.d/05lvm
%{_sysconfdir}/schroot/setup.d/05union
%{_sysconfdir}/schroot/setup.d/10mount
%{_sysconfdir}/schroot/setup.d/15binfmt
%{_sysconfdir}/schroot/setup.d/15killprocs
%{_sysconfdir}/schroot/setup.d/20copyfiles
%{_sysconfdir}/schroot/setup.d/20nssdatabases
%{_sysconfdir}/schroot/setup.d/50chrootname
%{_sysconfdir}/schroot/setup.d/70services
%{_sysconfdir}/schroot/setup.d/99check
%dir %{_libexecdir}/schroot
%{_libexecdir}/schroot/listmounts
%{_libexecdir}/schroot/mount
%dir %{_localstatedir}/lib/schroot
%{_localstatedir}/lib/schroot/session
%{_localstatedir}/lib/schroot/mount
%{_datadir}/%{name}/setup/common-config
%{_datadir}/%{name}/setup/common-data
%{_datadir}/%{name}/setup/common-functions
%{_mandir}/man1/schroot.1.*
%{_mandir}/de/man1/schroot.1.*
%{_mandir}/fr/man1/schroot.1.*
%{_mandir}/man5/schroot*.5.*
%{_mandir}/man7/schroot*.7.*
%{_mandir}/de/man5/schroot*.5.*
%{_mandir}/de/man7/schroot*.7.*
%{_mandir}/fr/man5/schroot*.5.*
%{_mandir}/fr/man7/schroot*.7.*

%files -n dchroot
%{_bindir}/dchroot*
%{_mandir}/man1/dchroot*.1.*
%{_mandir}/de/man1/dchroot*.1.*
%{_mandir}/fr/man1/dchroot*.1.*

%files -n %libname
%{_libdir}/*.so.*

%files -n %devname
%dir %{_includedir}/sbuild
%{_includedir}/sbuild/*
%{_libdir}/libsbuild.so
%{_libdir}/pkgconfig/sbuild.pc



%changelog
* Fri Sep 13 2024 wally <wally> 1.7.2-29.mga10
+ Revision: 2095518
- rebuild for boost 1.86.0

* Sat Jun 22 2024 wally <wally> 1.7.2-28.mga10
+ Revision: 2076182
- rebuild for boost 1.85.0
- update URL

* Fri Jan 12 2024 wally <wally> 1.7.2-27.mga10
+ Revision: 2030593
- rebuild for boost 1.84.0

* Thu Sep 28 2023 daviddavid <daviddavid> 1.7.2-26.mga10
+ Revision: 1991710
- add patch to compile with c++17
+ wally <wally>
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 1.7.2-25.mga9
+ Revision: 1926528
- rebuild for boost 1.81.0

* Mon Aug 29 2022 ns80 <ns80> 1.7.2-24.mga9
+ Revision: 1881615
- backport upstream patch for CVE-2022-2787 (mga#30758)

* Sun Jul 03 2022 wally <wally> 1.7.2-23.mga9
+ Revision: 1867309
- rebuild for boost 1.79.0

* Fri Apr 01 2022 umeabot <umeabot> 1.7.2-22.mga9
+ Revision: 1838111
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 1.7.2-21.mga9
+ Revision: 1762658
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 1.7.2-20.mga9
+ Revision: 1744691
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.7.2-19.mga9
+ Revision: 1723016
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 1.7.2-18.mga8
+ Revision: 1666815
- rebuild for boost 1.75.0

* Mon Dec 21 2020 luigiwalser <luigiwalser> 1.7.2-17.mga8
+ Revision: 1662422
- update URL
- add patch from fedora to fix build with po4a
+ wally <wally>
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 1.7.2-15.mga8
+ Revision: 1578525
- udpate lvm2 BR
- rebuild for boost 1.73.0
+ danf <danf>
- Switch URLs from http: to https:

* Wed Feb 19 2020 umeabot <umeabot> 1.7.2-14.mga8
+ Revision: 1544897
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1.7.2-13.mga8
+ Revision: 1483431
- rebuild for boost 1.72.0
- build with new cmake macros

* Tue Oct 16 2018 wally <wally> 1.7.2-12.mga7
+ Revision: 1321095
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 1.7.2-11.mga7
+ Revision: 1300940
- Mageia 7 Mass Rebuild

* Mon Dec 25 2017 wally <wally> 1.7.2-10.mga7
+ Revision: 1184706
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 1.7.2-9.mga7
+ Revision: 1178060
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1.7.2-8.mga7
+ Revision: 1154544
- rebuild with latest boost

* Sun Dec 27 2015 daviddavid <daviddavid> 1.7.2-7.mga6
+ Revision: 916120
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 fwang <fwang> 1.7.2-6.mga6
+ Revision: 883745
- rebuild for new boost

* Thu Aug 27 2015 cjw <cjw> 1.7.2-5.mga6
+ Revision: 870085
- patch3: fix build for new C++ standard
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 1.7.2-4.mga6
+ Revision: 740439
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.7.2-3.mga5
+ Revision: 689053
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sun Jun 15 2014 philippem <philippem> 1.7.2-2.mga5
+ Revision: 636478
- fix build with correct regex checks

* Mon Mar 10 2014 philippem <philippem> 1.7.2-1.mga5
+ Revision: 601864
- Update to 1.7.2, fix build (mga#12976) thanks to Oleg Bosis

* Sat Feb 08 2014 barjac <barjac> 1.7.0-3.mga5
+ Revision: 586781
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 1.7.0-2.mga4
+ Revision: 536217
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 fwang <fwang> 1.7.0-1.mga4
+ Revision: 483730
- update file list
- force c++11
- new version 1.7.0

* Mon Sep 23 2013 fwang <fwang> 1.6.5-2.mga4
+ Revision: 483723
- rebuild for new boost

* Sun Jul 21 2013 fwang <fwang> 1.6.5-1.mga4
+ Revision: 456763
- new version 1.6.5

* Mon Jul 08 2013 fwang <fwang> 1.6.3-7.mga4
+ Revision: 451212
- rebuild for new boost

* Fri May 31 2013 philippem <philippem> 1.6.3-6.mga4
+ Revision: 433885
- fix depend on a set of devel packages (mga#10166)

* Thu Apr 11 2013 ennael <ennael> 1.6.3-5.mga3
+ Revision: 409606
- rebuild for boost 1.53

* Mon Jan 14 2013 umeabot <umeabot> 1.6.3-4.mga3
+ Revision: 381806
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.6.3-3.mga3
+ Revision: 333014
- rebuild for new boost

* Thu Sep 20 2012 philippem <philippem> 1.6.3-2.mga3
+ Revision: 296375
- add libsbuild packages

* Sun Sep 16 2012 philippem <philippem> 1.6.3-1.mga3
+ Revision: 294557
- New version 1.6.3

* Tue Jul 31 2012 fwang <fwang> 1.4.25-3.mga3
+ Revision: 276823
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 1.4.25-2.mga3
+ Revision: 249719
- rebuild for new boost

* Mon Mar 05 2012 philippem <philippem> 1.4.25-1.mga2
+ Revision: 218518
- Update to 1.4.25.

* Mon Nov 28 2011 fwang <fwang> 1.4.23-2.mga2
+ Revision: 173542
- rebuild for new boost

* Tue Sep 27 2011 philippem <philippem> 1.4.23-1.mga2
+ Revision: 149327
- update to new upstream 1.4.23 version
+ fwang <fwang>
- fix group
+ stormi <stormi>
- update release to ensure higher version than in mageia 1

* Tue Jun 28 2011 ahmad <ahmad> 1.4.22-1.mga2
+ Revision: 115195
- Add a patch to fix build with boost
- Add a dchroot sub-package
+ fwang <fwang>
- use configure2_5x
- use configure2_5x
- rebuild for new boost
+ philippem <philippem>
- New upstream stable release 1.4.22
  + Don't use rbind when mounting filesystems in the chroot
  + Session metadata includes the original chroot name
  + Improved man pages

* Mon Apr 25 2011 philippem <philippem> 1.4.21-2.mga1
+ Revision: 90249
-add patch for stat -add buildrequires and suggests btrfs-progs

* Fri Apr 22 2011 philippem <philippem> 1.4.21-1.mga1
+ Revision: 89742
- imported package schroot


* Fri Apr 22 2011 Philippe Makowski <philippem@mageia.org> - 1.4.21-mga1
- import in mageia from fedora

* Mon Mar 14 2011 Zach Carter <z.carter@f5.com> - 1.4.21-1
- rebuild for boost 1.46.1
- update to 1.4.21

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.19-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb 07 2011 Zach Carter <z.carter@f5.com> - 1.4.19-1
- rebuild for new boost
- fix boost 1.46 build issue: leaf() function renamed to filename()
- update to 1.4.19

* Sun Feb 06 2011 Thomas Spura <tomspur@fedoraproject.org> - 1.4.10-2
- rebuild for new boost

* Mon Aug 16 2010 Zach Carter <z.carter@f5.com> - 1.4.10-1
- update to 1.4.10

* Fri Jul 30 2010 Zach Carter <z.carter@f5.com> - 1.4.2-6
- rebuild for boost 1.44 update

* Mon Jul 19 2010 Zach Carter <z.carter@f5.com> - 1.4.2-5
- fix configure and configure.ac to correct boost function call

* Fri Jul 16 2010 Zach Carter <z.carter@f5.com> - 1.4.2-4
- cat config.log on failure.

* Fri Jul 16 2010 Zach Carter <z.carter@f5.com> - 1.4.2-3
- Add some LIBS="-l<lib>" statements to fix build break.

* Wed Jul  7 2010 Zach Carter <z.carter@f5.com> - 1.4.2-2
- Licensing Guidelines Update - add license to dchroot subpackage.

* Thu May 27 2010 Zach Carter <z.carter@f5.com> - 1.4.2-1
- update to 1.4.2
- require libuuid-devel
- add /sbin directories to path in /etc/schroot/default/config BZ588200

* Sat Feb 13 2010 Zach Carter <z.carter@f5.com> - 1.2.3-5
- Specifically call out -lboost_system BZ564770

* Fri Jan 22 2010 Rahul Sundaram <sundaram@fedoraproject.org> - 1.2.3-4
- Rebuild for Boost soname bump
- Fix more than one changelog

* Mon Aug  3 2009 Zach Carter <z.carter@f5.com> - 1.2.3-3
- re-add /etc/schroot/chroot.d directory

* Tue Jul 14 2009 Zach Carter <z.carter@f5.com> - 1.2.3-2
- fix "file listed twice" warnings

* Tue Jul 14 2009 Zach Carter <z.carter@f5.com> - 1.2.3-1
- new upstream version
- compile with --enable-static --disable-shared
- improve dchroot description
- define directory ownership
- add + to GPLv3 license definition

* Tue May  5 2009 Zach Carter <z.carter@f5.com> - 1.2.2-2
- schroot-bind-shm patch to fix DOS issue 

* Sat Apr 25 2009 Zach Carter <z.carter@f5.com> - 1.2.2-1
- update to 1.2.2

* Wed Nov  5 2008 Zach Carter <z.carter@f5.com> - 1.2.1-2
- move libsbuild subpackage into main package
- remove duplicate doc entries
- disable rpath
- defattr for dchroot files

* Mon Sep 15 2008 Zach Carter <z.carter@f5.com> - 1.2.1-1
- bump version to 1.2.1

* Tue May 20 2008 Zach Carter <z.carter@f5.com> - 1.2.0-1
- move dchroot.1.gz to correct subpackage
- removed superfluous Requires: statements
- moved i18n files into libsbuild subpackage
- removed tmpfs patch

* Mon May 12 2008 Zach Carter <z.carter@f5.com> - 1.2.0-1
- Initial version

